==> multispaeti-0.1.0.tar.gz: multispaeti-0.1.0/README.md <==
# multiSPAETI*

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Code style: Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)

`multispaeti` is a Python implementation of
[MULTISPATI-PCA](https://doi.org/10.3170/2007-8-18312) /
[spatialPCA](https://doi.org/10.1038/hdy.2008.34).

## Installation

`multispaeti` will be made available on [PyPi](https://pypi.org/) and
[conda-forge](https://conda-forge.org/). For detailed installation instructions
please refer to the [documentation](https://multispaeti.readthedocs.io/en/stable/installation.html).

## Documentation

For documentation of the package please refer to the [ReadTheDocs page](https://multispaeti.readthedocs.io)

## Versioning

This project follows the [SemVer](https://semver.org/) guidelines for versioning.

## License

This project is licensed under the MIT License - for details please refer to the
[LICENSE](./LICENSE) file.

## Notes
\* [Späti](https://en.wikipedia.org/wiki/Sp%C3%A4tkauf)

==> multispaeti-1.0.0.tar.gz: multispaeti-1.0.0/README.md <==
# multiSPAETI*

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Code style: Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)

`multispaeti` is a Python implementation of
[MULTISPATI-PCA](https://doi.org/10.3170/2007-8-18312) /
[spatialPCA](https://doi.org/10.1038/hdy.2008.34).

## Installation

`multispaeti` is available from [PyPI](https://pypi.org/project/multispaeti/)

```bash
pip install multispaeti
```

and [conda-forge](https://anaconda.org/conda-forge/multispaeti)

```bash
conda install conda-forge::multispaeti
```

For detailed installation instructions please refer to the
[documentation](https://multispaeti.readthedocs.io/en/stable/installation.html).

## Documentation

For documentation of the package please refer to the [ReadTheDocs page](https://multispaeti.readthedocs.io)

## Versioning

This project follows the [SemVer](https://semver.org/) guidelines for versioning.

## License

This project is licensed under the MIT License - for details please refer to the
[LICENSE](./LICENSE) file.

## Notes
\* [Späti](https://en.wikipedia.org/wiki/Sp%C3%A4tkauf)
